/*
 * Copyright (C) 2006 Alex Aranda
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package com.fleax.ant;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileWriter;
import java.util.Date;
import java.util.PropertyResourceBundle;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

/**
 * Ant task to generate a build.properties file with date of task execution and incremental build number
 * This ant task can be used in build scripts to generate incremental number version files 
 */

public class BuildNumberGenerator extends Task {
	
	public BuildNumberGenerator() {
		super();
	}
	
	@Override
	public void execute() throws BuildException {
		super.execute();
		System.out.println("Generating build number");
		try {
			File f = new File(BuildNumberConstants.BUILD_NUMBER_FILE);
			FileWriter fw;
			if (!f.exists()) {
				f.createNewFile();
				fw = new FileWriter(f);
				fw.append(BuildNumberConstants.BUILD_NUMBER_PROPERTY + "=1" + "\r\n");
			}
			else {
				PropertyResourceBundle file = new PropertyResourceBundle(new FileInputStream(f));
				Integer build = Integer.parseInt(file.getString(BuildNumberConstants.BUILD_NUMBER_PROPERTY));
				fw = new FileWriter(f);
				fw.append(BuildNumberConstants.BUILD_NUMBER_PROPERTY + "=" + (build+1) + "\r\n");
			}
			fw.append(BuildNumberConstants.BUILD_DATE_PROPERTY + "=" + BuildNumberConstants.DATE_FORMATTER.format(new Date()) + "\r\n");
			fw.flush();
			fw.close();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

}
